@@ -282,30 +282,6 @@ def RunnerClass(request):
     return request.param
 
 
-# decorator to force coverage on function.
-# used to get coverage using multiprocessing.
-def cov_dec(func): # pragma: no cover
-    try:
-        import coverage
-    except:
-        # coverage should not be required
-        return func
-    def wrap(*args, **kwargs):
-        cov = coverage.coverage(data_suffix=True)
-        cov.start()
-        try:
-            return  func(*args, **kwargs)
-        finally:
-            cov.stop()
-            cov.save()
-    return wrap
-
-
-# monkey patch function executed in a subprocess to get coverage
-# TODO - disabled because it was not working anymore...
-#runner.MRunner.execute_task = cov_dec(runner.MRunner.execute_task)
-
-
 def ok(): return "ok"
 def ok2(): return "different"
 
@@ -499,6 +475,7 @@ class TestRunner_run_tasks(object):
         my_runner.finish()
 
 
+@pytest.mark.skipif('not runner.MRunner.available()')
 class TestMReporter(object):
     class MyRunner(object):
         def __init__(self):
@@ -517,10 +494,9 @@ class TestMReporter(object):
         mp_reporter = runner.MReporter(fake_runner, reporter)
         assert hasattr(mp_reporter, 'add_success')
         assert not hasattr(mp_reporter, 'no_existent_method')
-# python2.5 dont have class decorators
-pytest.mark.skipif('not runner.MRunner.available()')(TestMReporter)
 
 
+@pytest.mark.skipif('not runner.MRunner.available()')
 class TestMRunner_get_next_task(object):
     # simple normal case
     def test_run_task(self, reporter, depfile):
@@ -574,10 +550,10 @@ class TestMRunner_get_next_task(object):
         assert 0 == run.free_proc
         assert isinstance(run.get_next_task(None), runner.Hold)
         assert 1 == run.free_proc
-# python2.5 dont have class decorators
-pytest.mark.skipif('not runner.MRunner.available()')(TestMRunner_get_next_task)
 
 
+
+@pytest.mark.skipif('not runner.MRunner.available()')
 class TestMRunner_start_process(object):
     # 2 process, 3 tasks
     def test_all_processes(self, reporter, monkeypatch, depfile):
@@ -632,10 +608,9 @@ class TestMRunner_start_process(object):
         assert 2 == len(proc_list)
         assert t1.name == task_q.get().name
         assert isinstance(task_q.get(), runner.Hold)
-# python2.5 dont have class decorators
-pytest.mark.skipif('not runner.MRunner.available()')(TestMRunner_start_process)
 
 
+@pytest.mark.skipif('not runner.MRunner.available()')
 class TestMRunner_execute_task(object):
     def test_hold(self, reporter, depfile):
         run = runner.MRunner(depfile.name, reporter)
@@ -647,6 +622,3 @@ class TestMRunner_execute_task(object):
         run.finish()
         # nothing was done
         assert result_q.empty() # pragma: no cover (coverage bug?)
-# python2.5 dont have class decorators
-pytest.mark.skipif('not runner.MRunner.available()')(TestMRunner_execute_task)
-
